<?php
/**
 * moduagency functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package moduagency
 */

if ( ! function_exists( 'moduagency_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function moduagency_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on moduagency, use a find and replace
		 * to change 'moduagency' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'moduagency', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		
		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary / Main Menu', 'moduagency' ),
			'top_menu' => esc_html__( 'Top Right Menu', 'moduagency' ),
			
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'moduagency_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
		
		// Add theme editor style.
		add_editor_style( 'assets/editor-style.css' );
	}
endif;
add_action( 'after_setup_theme', 'moduagency_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function moduagency_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'moduagency_content_width', 640 );
}
add_action( 'after_setup_theme', 'moduagency_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function moduagency_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'moduagency' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'moduagency' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title"><span>',
		'after_title'   => '</span></h4>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget', 'moduagency' ),
		'id'            => 'footer',
		'description'   => esc_html__( 'Add widgets here.', 'moduagency' ),
		'before_widget' => '<div id="%1$s" class="widget col-md-4 col-xs-12 footer-item-width %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget-title">',
		'after_title'   => '</h6>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Front Page Slider', 'moduagency' ),
		'id'            => 'front_page_sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'moduagency' ),
		'before_widget' => '<div id="%1$s" class="%2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title screen-reader-text">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Page Slider', 'moduagency' ),
		'id'            => 'blog_page_sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'moduagency' ),
		'before_widget' => '<div id="%1$s" class="%2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title screen-reader-text">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'moduagency_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function moduagency_scripts() {
	
	wp_enqueue_style( 'google-fonts', 'https://fonts.googleapis.com/css?family=Open+Sans:400,600,700|Poppins:400,500,600' );
	
	/* vendor css */
	wp_enqueue_style( 'bootstrap', get_theme_file_uri( '/vendor/bootstrap/bootstrap.css' ), '3.3.7' );
	wp_enqueue_style( 'font-awesome', get_theme_file_uri( '/vendor/font-awesome/css/font-awesome.css' ), '4.7.0' );
	wp_enqueue_style( 'bi-icon', get_theme_file_uri( '/vendor/bicon/css/bicon.css' ), '4.7.0' );
	wp_enqueue_style( 'owl-carousel', get_theme_file_uri( '/vendor/owlcarousel/assets/owl-carousel.css' ), '2.2.0' );
	wp_enqueue_style( 'hover-css', get_theme_file_uri( '/vendor/hover.css' ), '2.2.0' );
	wp_enqueue_style( 'magnific-popup', get_theme_file_uri( '/vendor/magnific-popup/magnific-popup.css' ), '1.1.0' );
	
	wp_enqueue_style( 'moduagency-style', get_stylesheet_uri() );
	wp_enqueue_style( 'moduagency-responsive', get_theme_file_uri( '/assets/responsive.css' ), '1.0.0' );
	
	/* vendor JS */
	wp_enqueue_script( 'bootstrap-js', get_theme_file_uri( '/vendor/bootstrap/bootstrap.js' ), 0, '3.3.7', true );
	wp_enqueue_script( 'jquery-owl-carousel', get_theme_file_uri( '/vendor/owlcarousel/owl-carousel.js' ), 0, '2.2.0',true );
	wp_enqueue_script( 'jquery-magnific-popup', get_template_directory_uri().'/vendor/magnific-popup/jquery.magnific-popup.js', 0, '1.1.0',true );
	wp_enqueue_script( 'jquery-moduagency', get_theme_file_uri( '/assets/moduagency.js' ), array('jquery'), '1.0.0', true);
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'moduagency_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
//require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}

/**
 * Load customizer.
 */
require get_template_directory() . '/inc/customizer/customizer.php';


require get_template_directory() . '/inc/post-hooks.php';

/**
 * wp-bootstrap-navwalker.
 */
require get_template_directory() . '/vendor/wp-bootstrap-navwalker/wp-bootstrap-navwalker.php';

/**
 * Load breadcrumbs
 */
require get_template_directory() . '/vendor/breadcrumbs/breadcrumbs.php';

/**
 * layout-hook.
 */
require get_template_directory() . '/inc/layout-hook.php';



/**
 * TGM PLUGINS.
 */
require get_template_directory() . '/inc/tgm/recommend-plugins.php';


require get_template_directory() . '/inc/pro/admin-page.php';