<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package moduagency
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}



/**------------------------------------------------
* 			Header Layout Container
* -------------------------------------------------*/

if( !function_exists('moduagency_header_top_container') ) :
	/**
	 * Load Header.
	 *
	 * @since 1.0.0
	 */
	function moduagency_header_top_container(){
		if( moduagency_get_option('topbar_defaults') == 1 ) :
		
	 ?>
     	<section class="top-header">
				<div class="container">
					<div class="clear-fix">
						<ul class="left-side float-left">
							<li><i class="fa fa-phone"></i> <?php  echo esc_html ( moduagency_get_option('topbar_phone') ); ?></li>
							<li><i class="fa fa-envelope-open-o"></i> <?php  echo esc_html ( moduagency_get_option('topbar_email') ); ?></li>
                            <li><i class="fa fa-map-marker"></i> <?php  echo esc_html ( moduagency_get_option('topbar_address') ); ?></li>
						</ul> <!-- /.left-side -->
                        <?php
                        wp_nav_menu( array(
                            'theme_location'    => 'top_menu',
                            'depth'             => 1,
                            'container'         => 'ul',
                            'menu_class'        => 'right-side float-right',
							'fallback_cb'   	=> 'moduagency_default_menu',
						  )
                        );
                        ?>
					</div> <!-- /.clear-fix -->
				</div> <!-- /.container -->
			</section>
     <?php
	 endif;
	}
	
	add_action('moduagency_header_layout','moduagency_header_top_container',10);
	
endif;


if( !function_exists('moduagency_middle_container') ) :
	/**
	 * header middle container.
	 *
	 * @since 1.0.0
	 */
	function moduagency_middle_container(){
	 ?>
        <div class="middle-header">
            <div class="container">
                <div class="row">
                    <div class="col-lg-4 col-md-3 col-xs-12">
                        <div class="them-logo">
                        
						<?php
                        if ( function_exists( 'the_custom_logo' ) && has_custom_logo() ) {
                        	the_custom_logo();
                        }else{
                        ?>
                       		<h3><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h3>
                        	<?php $description = get_bloginfo( 'description', 'display' );
                        if ( $description || is_customize_preview() ) : ?>
                       		 <p class="site-description"><?php echo esc_html($description); ?></p>
                        <?php endif; ?>
                        
                        <?php }?>  
                        
                        </div><!-- /.them-logo -->
                    </div> <!-- /.col -->
                  
                    <?php if ( moduagency_get_option('dialog_defaults') == 1 && moduagency_get_option('moduagency_award') !="" )  :?>	
                    <div class="col-lg-8 col-md-9 col-xs-12">
                        <div class="middle-header-contant">
                            <ul class="clear-fix ">
                            	<?php 
								
								foreach ( moduagency_get_option('moduagency_award') as $key => $text): 
								?>
                                 <li><h4><?php echo esc_html( $text['title'] );?></h4><span><?php echo esc_html( $text['text'] );?></span></li>
                                <?php
								endforeach;
								?>
                            </ul> <!-- /.clear-fix -->
                        </div> <!-- /.middle-header-contant -->
                    </div> <!-- /.col -->
                    <?php endif;?>
                </div> <!-- /.row -->
            </div> <!-- /.container -->
        </div>
     <?php
	}
	
	add_action('moduagency_header_layout','moduagency_middle_container',20);
	
endif;

if( !function_exists('moduagency_nav_container') ) :
	/**
	 * header middle container.
	 *
	 * @since 1.0.0
	 */
	function moduagency_nav_container(){
	 ?>
        <div class="theme-main-menu">
        <div class="container">
            <div class="main-menu clear-fix">
                <!-- Menu -->
                <nav class="navbar">
                    <!-- Brand and toggle get grouped for better mobile display -->
                    <div class="navbar-header">
                        <button type="button" class="navbar-toggle collapsed tran3s" data-toggle="collapse" data-target="#navbar-collapse-1" aria-expanded="false">
                            <span class="sr-only tran3s">Toggle navigation</span>
                            <span class="icon-bar tran3s"></span>
                            <span class="icon-bar tran3s"></span>
                            <span class="icon-bar tran3s"></span>
                        </button>
                    </div>
                    
                    <!-- Collect the nav links, forms, and other content for toggling -->
                    <div class="collapse navbar-collapse" id="navbar-collapse-1">
                     <?php
                        wp_nav_menu( array(
                            'theme_location'    => 'primary',
                            'depth'             => 3,
                            'container'         => 'ul',
                            'container_class'   => 'collapse navbar-collapse navbar-left',
                            'container_id'      => 'navbar',
                            'menu_class'        => 'nav navbar-nav',
                          	'fallback_cb'       => 'WP_Bootstrap_Navwalker::fallback',
                            'walker'            => new WP_Bootstrap_Navwalker()
						  )
                        );
                        ?>
                     
                    </div><!-- /.navbar-collapse -->
                </nav>
        
                <div class="float-right">
                    <div class="search-button-content clear-fix">
                    
                    	<?php 
						if ( class_exists( 'WooCommerce' ) && in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
						?>
                    	<a href="<?php echo esc_url ( wc_get_cart_url() );?>" class="cart-icon tran3s"><i class="bi bi-shopping-cart-full"></i> <span><?php echo esc_html(WC()->cart->get_cart_contents_count() );?></span></a>
                    	<?php } ?>
                       
            <?php if ( moduagency_get_option('social_profile') == 1 
			  && moduagency_get_option('moduagency_social_profile_link') !=""
			  && count( moduagency_get_option('moduagency_social_profile_link') ) > 0 ) :?>	
             <?php $social_link = moduagency_get_option('moduagency_social_profile_link');?>
             <ul class="main-menu-icon">
				<?php 
                foreach ($social_link['social'] as $key => $link): 
               		 if( $link != ""):
                ?>
                	<li><a href="<?php echo esc_url( $link );?>"target="_blank"><i class="fa <?php echo esc_attr($key);?>" aria-hidden="true"></i></a></a></li>
                <?php endif; 
                endforeach;
                ?>
            </ul>
            <?php endif;?>
                      
                        
                    </div> <!-- /.right-content -->
                </div> <!-- /.float-right -->
            </div> <!-- / main-menu -->
        </div> <!-- /.container main-menu -->
        </div>
     <?php
	}
	
	add_action('moduagency_header_layout','moduagency_nav_container',30);
	
endif;




/**------------------------------------------------
* 			Foooter Layout Container
* -------------------------------------------------*/

if( !function_exists('moduagency_footer_start') ) :
	/**
	 * Footer Wrp Start.
	 *
	 * @since 1.0.0
	 */
	function moduagency_footer_start(){
		?>
        <footer class="main-footer">
        <?php
	}
	add_action('moduagency_footer_layout','moduagency_footer_start',10);
endif;

if( !function_exists('moduagency_footer_call_to_action') ) :
	/**
	 * Footer call to action.
	 *
	 * @since 1.0.0
	 */
	function moduagency_footer_call_to_action(){
		if( moduagency_get_option('active_action') == 1 ) :
		?>
        <div class="footer-call-to-action">
            <div class="container">
                <div class="row">	
                    <div class="col-md-12">	
                        <div class="call-to-action-sec">
                            <div class="call-to-action-overlay"></div>
                            <div class="col-md-8 col-sm-9">
                                <div class="call-to-action-text">
                                    <h2><?php echo esc_html( moduagency_get_option('call_to_action_title') );?></h2>
                                    <p><?php echo esc_html( moduagency_get_option('call_to_action_sub') );?></p>
                                </div>												
                            </div>
                        <?php if( moduagency_get_option('call_to_action_link') !="" && moduagency_get_option('call_to_action_btn') !=""  ):?>				
                            <div class="col-md-4 col-sm-3">
                                <div class="call-to-action-text">
                                    <a href="<?php echo esc_url( moduagency_get_option('call_to_action_link') );?>" class="btn"><?php echo esc_html( moduagency_get_option('call_to_action_btn') );?></a>
                                </div>												
                            </div>	
                          <?php endif;?>										
                        </div>					
                    </div>					
                </div>					
            </div>
        </div>
        <div class="footer-call-to-action-space"></div> 
        <?php
		endif;
	}
	add_action('moduagency_footer_layout','moduagency_footer_call_to_action',20);
endif;


if( !function_exists('moduagency_footer_main_container') ) :
	/**
	 * Footer Main Container.
	 *
	 * @since 1.0.0
	 */
	function moduagency_footer_main_container(){
		?>
       <div class="container">
         <!-- /.contact-info -->
        <?php if (  is_active_sidebar( 'footer' ) ) :?>
        <div class="footer-item-wrapper">
            <div class="row">
               <?php dynamic_sidebar( 'footer' ); ?>
            </div> <!-- /.row -->
        </div> <!-- /.footer-item-wrapper -->
        <?php  endif;?>
        <div class="footer-bottom clear-fix">
            <p class="float-left">
          		  <?php echo esc_html ( moduagency_get_option('copyright_text') ); ?> 
                        <a href="<?php /* translators:straing */ echo esc_url( esc_html__( 'https://wordpress.org/', 'moduagency' ) ); ?>"><?php /* translators:straing */  printf( esc_html__( '- Proudly powered by %s .', 'moduagency' ), 'WordPress' ); ?></a>
                        
                        <?php
                        printf( /* translators:straing */  esc_html__( 'Theme : %1$s by %2$s.', 'moduagency' ), 'ModuAgency', '<a href="' . esc_url( __( 'https://athemeart.com', 'moduagency' ) ) . '" target="_blank">' . esc_html__( 'aThemeArt', 'moduagency' ) . '</a>' ); ?>
            
            </p>
            
             <?php if ( moduagency_get_option('social_profile_bottom') == 1 
				 && moduagency_get_option('moduagency_social_profile_link') !=""
				  && count( moduagency_get_option('moduagency_social_profile_link') ) >0  
			 ) :?>	
             <?php $social_link = moduagency_get_option('moduagency_social_profile_link');?>
            <ul class="float-right">
				<?php 
                foreach ($social_link['social'] as $key => $link): 
               		 if( $link != ""):
                ?>
                	<li><a href="<?php echo esc_url( $link );?>"target="_blank"><i class="fa <?php echo esc_attr($key);?>" aria-hidden="true"></i></a></a></li>
                <?php endif; 
                endforeach;
                ?>
            </ul>
            <?php endif;?>
            
        </div> <!-- /.footer-bottom -->
    </div>
        <?php
	}
	add_action('moduagency_footer_layout','moduagency_footer_main_container',30);
endif;

if( !function_exists('moduagency_footer_end') ) :
	/**
	 * Footer WRP End.
	 *
	 * @since 1.0.0
	 */
	function moduagency_footer_end(){
		?>
        </footer> <!-- /.main-footer -->
        <?php
	}
	add_action('moduagency_footer_layout','moduagency_footer_end',40);
endif;





/**------------------------------------------------
* 			Page Layout
* -------------------------------------------------*/


if( !function_exists('moduagency_page_wrp_container_start') ) :
	/**
	 * moduagency_page_wrp_container_start.
	 *
	 * @since 1.0.0
	 */
	function moduagency_page_wrp_container_start( ){
		?>
        <section class="main-container-wrp">
       	 <i class="fa fa-circle-thin style"></i>
       	 <div class="container">
        	<div class="row">
        <?php
	}
	add_action('moduagency_page_container_start','moduagency_page_wrp_container_start',10);
endif;

if( !function_exists('moduagency_page_column') ) :
	/**
	 *  page container column 
	 *
	 * @since 1.0.0
	 */
	function moduagency_page_column( $layout = 'pull-right' ){
		
		switch ( $layout ) {
			
		case 'no-sidebar':
			echo '<div class="col-lg-10 col-md-10 col-xs-12 pull-center">';
		break;
		
		case 'pull-left':
			echo '<div class="col-lg-8 col-md-8 col-xs-12 pull-right">';
		break;
		
		default:
			echo '<div class="col-lg-8 col-md-8 col-xs-12">';
		} 
	
      
	}
	add_action('moduagency_page_container_start','moduagency_page_column',20, 1);
endif;



if( !function_exists('moduagency_page_column_end') ) :
	/**
	 *  page container column end
	 *
	 * @since 1.0.0
	 */
	function moduagency_page_column_end(){
		?>
       		</div>
        <?php
	}
	add_action('moduagency_page_container_end','moduagency_page_column_end',10);
endif;

if( !function_exists('moduagency_page_sidebar') ) :
	/**
	 * load sidebar	 *
	 * @since 1.0.0
	 */
	function moduagency_page_sidebar( $layout = 'sidebar' ){
		
		if( $layout == 'no-sidebar' ) {  return false; }
		$float = ( $layout == 'pull-left' ) ? 'pull-left': '';
		?>
       		<div class="col-lg-4 col-md-4 col-xs-12 <?php echo esc_attr( $float );?>">
            	<?php get_sidebar(); ?>
            </div>
        <?php
	}
	add_action('moduagency_page_container_end','moduagency_page_sidebar',20);
endif;




if( !function_exists('moduagency_page_wrp_container_end') ) :
	/**
	 *  end wrp container
	 *
	 * @since 1.0.0
	 */
	function moduagency_page_wrp_container_end(){
		?>
                </div> <!-- /.row -->
            </div> <!-- /.container -->
        </section>
        <?php
	}
	add_action('moduagency_page_container_end','moduagency_page_wrp_container_end',30);
endif;

if ( ! function_exists( 'moduagency_hero_block_start' ) ) :
	/**
	 * Add title in custom header.
	 *
	 * @since 1.0.0
	 */
	function moduagency_hero_block_start() {
		$header_image = get_header_image();
		if( $header_image !="" ):
			$header_style = 'background: url('. esc_url( $header_image ) .') no-repeat center center;';
			$header_style .= ' background-attachment: scroll; background-size: cover; background-attachment: fixed;';
		else:
			$header_style = '';
		endif;
		?>
         <section>
            <div class="theme-hero-block inner-banner-bg-img-one" style=" <?php echo esc_attr($header_style);?>">
                <div class="banner-opacity">
                    <div class="container">
                        <div class="banner-content">
        <?php
	}
	add_action('moduagency_hero_block','moduagency_hero_block_start',10);
endif;

if ( ! function_exists( 'moduagency_hero_block_page_title' ) ) :
	/**
	 * Add title in custom header.
	 *
	 * @since 1.0.0
	 */
	function moduagency_hero_block_page_title() {
		if ( is_home() ) {
				echo '<h1 class="display-1">';
				echo bloginfo( 'name' );
				echo '</h1>';
				echo '<p class="subtitle">';
				echo esc_html(get_bloginfo( 'description', 'display' ));
				echo '</p>';
		}else if ( function_exists('is_shop') && apply_filters( 'woocommerce_show_page_title', true ) && is_shop() ){
			if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
				echo '<h1 class="title">';
				echo esc_html( woocommerce_page_title() );
				echo '</h1>';
				
			}
		}else if( function_exists('is_product_category') && is_product_category() ){
			echo '<h1 class="title">';
			echo esc_html( woocommerce_page_title() );
			echo '</h1>';
			echo '<div class="white_text">';
			do_action( 'woocommerce_archive_description' );
			echo '</div>';
			
		}elseif ( is_singular() ) {
			echo '<h1 class="display-1">';
			echo single_post_title( '', false );
			echo '</h1>';
		} elseif ( is_archive() ) {
			the_archive_title( '<h1 class="display-1">', '</h1>' );
		} elseif ( is_search() ) {
			echo '<h1 class="title">';
			printf( /* translators:straing */ esc_html__( 'Search Results for: %s', 'moduagency' ),  get_search_query() );
			echo '</h1>';
		} 
		
		  if ( function_exists('is_product') && is_product() ){
			do_action( 'moduagency_single_product_summary' );
		  }
	}
	add_action('moduagency_hero_block','moduagency_hero_block_page_title',20);
endif;



if ( ! function_exists( 'moduagency_hero_block_breadcrumbs' ) ) :
	/**
	 * Add breadcrumbs.
	 *
	 * @since 1.0.0
	 */
	function moduagency_hero_block_breadcrumbs() {
		
		/**
        * Hook - moduagency_breadcrumb.
        *
        * @hooked moduagency_breadcrumb - 10
        */
		do_action ( 'moduagency_breadcrumb' );
	}
	add_action('moduagency_hero_block','moduagency_hero_block_breadcrumbs',30);
endif;



if ( ! function_exists( 'moduagency_hero_block_end' ) ) :
	/**
	 *
	 * @since 1.0.0
	 */
	function moduagency_hero_block_end() {
		?>
                     </div> <!-- /.banner-content -->
                    </div> <!-- /.container -->
                </div> <!-- /.banner-opacity -->
            </div> <!-- /.theme-hero-block -->
        </section>
        <?php
	}
	add_action('moduagency_hero_block','moduagency_hero_block_end',40);
endif;



