<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package moduagency
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function moduagency_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'moduagency_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function moduagency_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'moduagency_pingback_header' );


if ( ! function_exists( 'moduagency_walker_comment' ) ) : 
	/**
	 * Implement Custom Comment template.
	 *
	 * @since 1.0.0
	 *
	 * @param $comment, $args, $depth
	 * @return $html
	 */
	  
	function moduagency_walker_comment($comment, $args, $depth) {
		
		
		?><li>
            <div class="media">
                <div class="media-left">
                   <?php if ( $args['avatar_size'] != 0 ) echo get_avatar( $comment, 70 ); ?>
                </div>
                <div class="media-body">
                    <div class="media-content last">
                        <h5 class="media-heading"><?php echo get_comment_author_link();?><span> <?php
							/* translators: 1: date, 2: time */
							printf( esc_html__('%1$s at %2$s', 'moduagency' ), get_comment_date(),  get_comment_time() );
							 ?></span></h5>
                        <p>  <?php comment_text(); ?></p>
                        
                         <?php 
					$args ['reply_text'] =  esc_html__( 'Reply', 'moduagency' );
                    comment_reply_link( array_merge( $args, array(  'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
                    </div>
                </div>
            </div>
           </li> 
		<?php
	}
	
	function moduagency_replace_reply_link_class($class){
		$class = str_replace("class='comment-reply-link", "class='reply", $class);
		return $class;
	}
	add_filter('comment_reply_link', 'moduagency_replace_reply_link_class');
endif;




if ( ! function_exists( 'moduagency_breadcrumb' ) ) :

	/**
	 * Breadcrumb.
	 *
	 * @since 1.0.0
	 */
	function moduagency_breadcrumb() {
		
			
		
		if ( ! function_exists( 'breadcrumb_trail' ) ) {
			
			require get_template_directory() . '/vendor/breadcrumbs/breadcrumbs';
		}

		$breadcrumb_args = array(
			'container'   => 'div',
			'show_browse' => false,
		);
	
		breadcrumb_trail( $breadcrumb_args );
	
		
		
	}

endif;
add_action( 'moduagency_breadcrumb', 'moduagency_breadcrumb',10 );


if( ! function_exists('moduagency_default_menu') ):
/**
	*  fallback default menu.
	*
	* @since 1.0.0
	*/
	function moduagency_default_menu(){
		if ( current_user_can( 'edit_theme_options' ) ) {	
	?>
        <ul class="right-side float-right">                  
           <li><a href="<?php echo esc_url( admin_url('nav-menus.php') ); ?>"><?php esc_html_e( 'Set Up menu here', 'moduagency' ); ?></a></li>
        </ul>
	<?php
		}
	}
endif;